@@ -1,4 +1,4 @@
-/*$Id: RulesParser.cpp,v 1.21 2006/12/21 08:40:15 jwrobel Exp $*/
+/*$Id: RulesParser.cpp,v 1.22 2007/02/13 00:11:14 jwrobel Exp $*/
 /* ***** BEGIN LICENSE BLOCK *****
  *  This file is part of Firekeeper.
  *
@@ -483,7 +483,7 @@ bool RulesParser::parseContent(char *rule, const char *name,
 
     /* BEGIN BAD JUJU..... */
     while(idx < end_ptr){
-	    TRACE("processing char: %c", *idx);
+	    /*TRACE("processing char: %c", *idx);*/
 	    switch(*idx){
             case '|':
 		    TRACE("Got bar... ");
